@@ -380,6 +380,9 @@ int pth_accept_ev(int s, struct sockaddr *addr, int *addrlen, pth_event_t ev_ext
     static pth_key_t ev_key = PTH_KEY_INIT;
     int rv;
 
+    pth_implicit_init();
+    pth_debug2("pth_accept_ev: enter from thread \"%s\"", pth_current->name);
+
     /* poll socket via accept */
     ev = NULL;
     while ((rv = pth_sc(accept)(s, addr, addrlen)) == -1
@@ -399,6 +402,7 @@ int pth_accept_ev(int s, struct sockaddr *addr, int *addrlen, pth_event_t ev_ext
                 return_errno(-1, EINTR);
         }
     }
+    pth_debug2("pth_accept_ev: leave to thread \"%s\"", pth_current->name);
     return rv;
 }
 
@@ -420,6 +424,10 @@ ssize_t pth_read_ev(int fd, void *buf, size_t nbytes, pth_event_t ev_extra)
     pth_implicit_init();
     pth_debug2("pth_read_ev: enter from thread \"%s\"", pth_current->name);
 
+    /* POSIX compliance */
+    if (nbytes == 0)
+        return 0;
+
     /* first directly poll filedescriptor for readability 
        to avoid unneccessary (and resource consuming because of context
        switches, etc) event handling through the scheduler */
@@ -470,6 +478,10 @@ ssize_t pth_write_ev(int fd, const void *buf, size_t nbytes, pth_event_t ev_extr
     pth_implicit_init();
     pth_debug2("pth_write_ev: enter from thread \"%s\"", pth_current->name);
 
+    /* POSIX compliance */
+    if (nbytes == 0)
+        return 0;
+
     /* first directly poll filedescriptor for writeability 
        to avoid unneccessary (and resource consuming because of context
        switches, etc) event handling through the scheduler */
@@ -547,6 +559,10 @@ ssize_t pth_readv_ev(int fd, const struct iovec *iov, int iovcnt, pth_event_t ev
     pth_implicit_init();
     pth_debug2("pth_readv_ev: enter from thread \"%s\"", pth_current->name);
 
+    /* POSIX compliance */
+    if (iovcnt <= 0)
+        return_errno(-1, EINVAL);
+
     /* first directly poll filedescriptor for readability 
        to avoid unneccessary (and resource consuming because of context
        switches, etc) event handling through the scheduler */
@@ -606,7 +622,7 @@ intern size_t pth_readv_faked(int fd, const struct iovec *iov, int iovcnt)
         return -1;
     
     /* read data into temporary buffer */
-    rv = read(fd, buffer, bytes);
+    rv = pth_sc(read)(fd, buffer, bytes);
 
     /* scatter read data into callers vector */
     if (rv > 0) {
@@ -646,6 +662,10 @@ ssize_t pth_writev_ev(int fd, const struct iovec *iov, int iovcnt, pth_event_t e
     pth_implicit_init();
     pth_debug2("pth_writev_ev: enter from thread \"%s\"", pth_current->name);
 
+    /* POSIX compliance */
+    if (iovcnt <= 0)
+        return_errno(-1, EINVAL);
+
     /* first directly poll filedescriptor for writeability 
        to avoid unneccessary (and resource consuming because of context
        switches, etc) event handling through the scheduler */
@@ -716,7 +736,7 @@ intern size_t pth_writev_faked(int fd, const struct iovec *iov, int iovcnt)
     }
 
     /* write continuous chunck of data */
-    rv = write(fd, buffer, bytes);
+    rv = pth_sc(write)(fd, buffer, bytes);
 
     /* remove the temporary buffer */ 
     errno_safe( free(buffer) );
